import * as dashboard from '../dashboard';
export type expr = TypeMath | TypeReduce | TypeResample | TypeClassicConditions | TypeThreshold | TypeSql;
export declare const defaultExpr: () => expr;
export interface TypeMath {
    datasource?: dashboard.DataSourceRef;
    expression: string;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "math";
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeMath: () => TypeMath;
export interface TypeReduce {
    datasource?: dashboard.DataSourceRef;
    expression: string;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    reducer: "sum" | "mean" | "min" | "max" | "count" | "last" | "median";
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    settings?: {
        mode: "dropNN" | "replaceNN";
        replaceWithValue?: number;
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "reduce";
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeReduce: () => TypeReduce;
export interface TypeResample {
    datasource?: dashboard.DataSourceRef;
    downsampler: "sum" | "mean" | "min" | "max" | "count" | "last" | "median";
    expression: string;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "resample";
    upsampler: "pad" | "backfilling" | "fillna";
    window: string;
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeResample: () => TypeResample;
export interface TypeClassicConditions {
    conditions: {
        evaluator: {
            params: number[];
            type: string;
        };
        operator: {
            type: "and" | "or" | "logic-or";
        };
        query: {
            params: string[];
        };
        reducer: {
            type: string;
        };
    }[];
    datasource?: dashboard.DataSourceRef;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "classic_conditions";
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeClassicConditions: () => TypeClassicConditions;
export interface TypeThreshold {
    conditions: {
        evaluator: {
            params: number[];
            type: "gt" | "lt" | "within_range" | "outside_range";
        };
        loadedDimensions?: any;
        unloadEvaluator?: {
            params: number[];
            type: "gt" | "lt" | "within_range" | "outside_range";
        };
    }[];
    datasource?: dashboard.DataSourceRef;
    expression: string;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "threshold";
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeThreshold: () => TypeThreshold;
export interface TypeSql {
    datasource?: dashboard.DataSourceRef;
    expression: string;
    hide?: boolean;
    intervalMs?: number;
    maxDataPoints?: number;
    queryType?: string;
    refId: string;
    resultAssertions?: {
        maxFrames?: number;
        type?: "" | "timeseries-wide" | "timeseries-long" | "timeseries-many" | "timeseries-multi" | "directory-listing" | "table" | "numeric-wide" | "numeric-multi" | "numeric-long" | "log-lines";
        typeVersion: number[];
    };
    timeRange?: {
        from: string;
        to: string;
    };
    type: "sql";
    _implementsDataqueryVariant(): void;
}
export declare const defaultTypeSql: () => TypeSql;
export interface TypeMathOrTypeReduceOrTypeResampleOrTypeClassicConditionsOrTypeThresholdOrTypeSql {
    TypeMath?: TypeMath;
    TypeReduce?: TypeReduce;
    TypeResample?: TypeResample;
    TypeClassicConditions?: TypeClassicConditions;
    TypeThreshold?: TypeThreshold;
    TypeSql?: TypeSql;
}
export declare const defaultTypeMathOrTypeReduceOrTypeResampleOrTypeClassicConditionsOrTypeThresholdOrTypeSql: () => TypeMathOrTypeReduceOrTypeResampleOrTypeClassicConditionsOrTypeThresholdOrTypeSql;
